Index: /trunk/MagicSoft/Mars/Changelog
===================================================================
--- /trunk/MagicSoft/Mars/Changelog	(revision 1087)
+++ /trunk/MagicSoft/Mars/Changelog	(revision 1088)
@@ -1,3 +1,16 @@
                                                                   -*-*- END -*-*-
+
+ 2001/11/16: Thomas Bretz
+
+   * mhist/MHMcCollectionArea.cc:
+     - set the ReadyToSave bit in CalcEfficiency.
+
+   * mmontecarlo/MMcThresholdCalc.cc:
+     - set the ReadyToSave bit after the calculation has been finished.
+
+   * mhist/MHMcRate.cc:
+     - set the ReadyToSave bit in CalcRate
+
+
 
  2001/11/16: Thomas Bretz
Index: /trunk/MagicSoft/Mars/mhist/MHMcRate.cc
===================================================================
--- /trunk/MagicSoft/Mars/mhist/MHMcRate.cc	(revision 1087)
+++ /trunk/MagicSoft/Mars/mhist/MHMcRate.cc	(revision 1088)
@@ -151,5 +151,5 @@
 // --------------------------------------------------------------------------
 //
-//  compute the trigger rate
+//  compute the trigger rate and set the ReadyToSave bit
 //
 void MHMcRate::CalcRate(Float_t trig, Float_t anal, Float_t simu) 
@@ -188,4 +188,6 @@
 
     fTriggerRate = trig*fShowerRate/simu + anal2*fBackTrig/back2;
+
+    SetReadyToSave();
 }
 
Index: /trunk/MagicSoft/Mars/mmontecarlo/MMcThresholdCalc.cc
===================================================================
--- /trunk/MagicSoft/Mars/mmontecarlo/MMcThresholdCalc.cc	(revision 1087)
+++ /trunk/MagicSoft/Mars/mmontecarlo/MMcThresholdCalc.cc	(revision 1088)
@@ -176,4 +176,6 @@
         sigma = hist.GetGaussSigma();
         hist.Fit(peak - fSqrt2*sigma, peak + fSqrt2*sigma);
+
+        hist.SetReadyToSave();
     }
     return kTRUE;

Index: /trunk/MagicSoft/Mars/mhist/MHMcCollectionArea.cc
===================================================================
--- /trunk/MagicSoft/Mars/mhist/MHMcCollectionArea.cc	(revision 1087)
+++ /trunk/MagicSoft/Mars/mhist/MHMcCollectionArea.cc	(revision 1088)
@@ -194,5 +194,6 @@
 // --------------------------------------------------------------------------
 //
 //  Calculate the Efficiency (collection area)
 //
 void MHMcCollectionArea::CalcEfficiency()
@@ -258,3 +259,5 @@
         fHistCol->SetBinError(ix, sqrt(errA));
     }
-}
+
+    SetReadyToSave();
+}
@@ -194,5 +194,6 @@
 // --------------------------------------------------------------------------
 //
-//  Calculate the Efficiency (collection area)
+//  Calculate the Efficiency (collection area) and set the 'ReadyToSave'
+//  flag
 //
 void MHMcCollectionArea::CalcEfficiency()